# eric7.Debugger.CallTraceViewer

Module implementing the Call Trace viewer widget.

### Global Attributes

None

### Classes

CallTraceViewer | Class implementing the Call Trace viewer widget.

### Functions

None

## CallTraceViewer

Class implementing the Call Trace viewer widget.

### Signals

sourceFile(str, int)
  emitted to show the source of a call/return point

### Derived from

QWidget, Ui_CallTraceViewer

### Class Attributes

None

### Class Methods

None

### Methods

CallTraceViewer | Constructor
__addCallTraceInfo | Private method to add an entry to the call trace viewer.
__clientExit | Private slot to handle a debug client terminating.
__setCallTraceEnabled | Private slot to set the call trace enabled status.
clear | Public slot to clear the call trace info.
isCallTraceEnabled | Public method to get the state of the call trace function.
on_callTrace_itemDoubleClicked | Private slot to open the double clicked file in an editor.
on_clearButton_clicked | Private slot to clear the call trace.
on_resizeButton_clicked | Private slot to resize the columns of the call trace to their contents.
on_saveButton_clicked | Private slot to save the call trace info to a file.
on_startTraceButton_clicked | Private slot to start call tracing.
on_stopCheckBox_clicked | Private slot to handle a click on the stop check box.
on_stopTraceButton_clicked | Private slot to start call tracing.
setProjectMode | Public slot to set the call trace viewer to project mode.

### Static Methods

None

#### CallTraceViewer (Constructor)

CallTraceViewer(debugServer, debugViewer, parent=None)

Constructor

debugServer (DebugServer)
  reference to the debug server object
debugViewer (DebugViewer)
  reference to the debug viewer object
parent (QWidget)
  reference to the parent widget

#### CallTraceViewer.__addCallTraceInfo

__addCallTraceInfo(isCall, fromFile, fromLine, fromFunction, toFile, toLine, toFunction, debuggerId)

Private method to add an entry to the call trace viewer.

isCall (bool)
  flag indicating a 'call'
fromFile (str)
  name of the originating file
fromLine (str)
  line number in the originating file
fromFunction (str)
  name of the originating function
toFile (str)
  name of the target file
toLine (str)
  line number in the target file
toFunction (str)
  name of the target function
debuggerId (str)
  ID of the debugger backend

#### CallTraceViewer.__clientExit

__clientExit(program, status, message, quiet, debuggerId)

Private slot to handle a debug client terminating.

program (str)
  name of the exited program
status (int)
  exit code of the debugged program
message (str)
  exit message of the debugged program
quiet (bool)
  flag indicating to suppress exit info display
debuggerId (str)
  ID of the debugger backend

#### CallTraceViewer.__setCallTraceEnabled

__setCallTraceEnabled(enabled)

Private slot to set the call trace enabled status.

enabled (bool)
  flag indicating the new state

#### CallTraceViewer.clear

clear()

Public slot to clear the call trace info.

#### CallTraceViewer.isCallTraceEnabled

isCallTraceEnabled()

Public method to get the state of the call trace function.

Return:
  flag indicating the state of the call trace function

Return Type:
  bool

#### CallTraceViewer.on_callTrace_itemDoubleClicked

on_callTrace_itemDoubleClicked(item, column)

Private slot to open the double clicked file in an editor.

item (QTreeWidgetItem)
  reference to the double clicked item
column (int)
  column that was double clicked

#### CallTraceViewer.on_clearButton_clicked

on_clearButton_clicked()

Private slot to clear the call trace.

#### CallTraceViewer.on_resizeButton_clicked

on_resizeButton_clicked()

Private slot to resize the columns of the call trace to their contents.

#### CallTraceViewer.on_saveButton_clicked

on_saveButton_clicked()

Private slot to save the call trace info to a file.

#### CallTraceViewer.on_startTraceButton_clicked

on_startTraceButton_clicked()

Private slot to start call tracing.

#### CallTraceViewer.on_stopCheckBox_clicked

on_stopCheckBox_clicked(checked)

Private slot to handle a click on the stop check box.

checked (bool)
  state of the check box

#### CallTraceViewer.on_stopTraceButton_clicked

on_stopTraceButton_clicked()

Private slot to start call tracing.

#### CallTraceViewer.setProjectMode

setProjectMode(enabled)

Public slot to set the call trace viewer to project mode.

In project mode the call trace info is shown with project relative path names.

enabled (bool)
  flag indicating to enable the project mode

Up